Object

Struct Object 

pub struct Object { /* private fields */ }
An object that can be shown on the screen

Implementations

Source

impl Object

pub fn show(&self, frame: &mut GraphicsFrame<'_>)

Show the object on the current frame.

Objects with the .show() function called first will be rendered above those which have .show() called on them afterwards. It is up to you to order the objects in the correct way before calling .show() on them.

pub fn new(sprite: impl Into<SpriteVram>) -> Self

Creates an object from a sprite in vram.

pub fn set_hflip(&mut self, flip: bool) -> &mut Self

Sets the horizontal flip, note that this only has a visible affect in Normal mode.
Use hflip to get the value

pub fn hflip(&self) -> bool

Returns the horizontal flip
Use set_hflip to set the value

pub fn set_vflip(&mut self, flip: bool) -> &mut Self

Sets the vertical flip, note that this only has a visible affect in Normal mode.
Use vflip to get the value

pub fn vflip(&self) -> bool

Returns the vertical flip
Use set_vflip to set the value

pub fn set_priority(&mut self, priority: Priority) -> &mut Self

Sets the priority of the object relative to the backgrounds priority.
Use priority to get the value

pub fn priority(&self) -> Priority

Returns the priority of the object
Use set_priority to set the value

pub fn set_pos(&mut self, position: impl Into<Vector2D<i32>>) -> &mut Self

Sets the position of the object.
Use pos to get the value

pub fn pos(&self) -> Vector2D<i32>

Returns the position of the object
Use set_pos to set the value

pub fn set_sprite(&mut self, sprite: impl Into<SpriteVram>) -> &mut Self

Sets the current sprite for the object.

pub fn set_graphics_mode(&mut self, mode: GraphicsMode) -> &mut Self

Sets the graphics mode of the object