Rgb15

Struct Rgb15 

#[repr(transparent)]
pub struct Rgb15(pub u16);
Represents a pixel on the GBA.

This is stored as a 15 bit number as 0b0bbbbbgggggrrrrr. You can see what would happen to your true-colour value by using the utility site in the agbrs.dev website.

Tuple Fields

0: u16

Implementations

Source

impl Rgb15

pub const BLACK: Rgb15

A black Rgb15 value

pub const WHITE: Rgb15

A white Rgb15 value

pub const fn new(value: u16) -> Self

Creates a new Rgb15 value. You should probably use Rgb15(<your number>) rather than this constructor, but it exists to use as a function reference when that is useful.