Vector2D

Struct Vector2D 

#[repr(C)]
pub struct Vector2D<T>
where T: Number,
{ pub x: T, pub y: T, }
A vector of two points: (x, y) represented by integers or fixed point numbers

Fields

x: T

The x coordinate

y: T

The y coordinate

Implementations

Source

impl<T> Vector2D<T>
where T: Number + Signed,

pub fn abs(self) -> Vector2D<T>

Calculates the absolute value of the x and y components.

pub fn manhattan_distance(self) -> T

Calculates the manhattan (or taxicab) distance, x.abs() + y.abs().

let v1: Vector2D<Num<i32, 8>> = (num!(3.), num!(4.)).into();
assert_eq!(v1.manhattan_distance(), 7.into());
Source

impl<I, const N: usize> Vector2D<Num<I, N>>

pub fn trunc(self) -> Vector2D<I>

Truncates the x and y coordinate, see Num::trunc

let v1: Vector2D<Num<i32, 8>> = (num!(1.56), num!(-2.2)).into();
let v2: Vector2D<i32> = (1, -2).into();
assert_eq!(v1.trunc(), v2);
pub fn floor(self) -> Vector2D<I>

Floors the x and y coordinate, see Num::floor

let v1: Vector2D<Num<i32, 8>> = vec2(num!(1.56), num!(-2.2));
let v2: Vector2D<i32> = (1, -3).into();
assert_eq!(v1.floor(), v2);
pub fn round(self) -> Vector2D<I>

Rounds the x and y coordinate, see Num::round

let v1: Vector2D<Num<i32, 8>> = vec2(num!(1.56), num!(-2.2));
let v2: Vector2D<i32> = (2, -2).into();
assert_eq!(v1.round(), v2);
pub fn try_change_base<J, const M: usize>(self) -> Option<Vector2D<Num<J, M>>>
where J: FixedWidthUnsignedInteger + TryFrom<I>,

Attempts to change the base returning None if the numbers cannot be represented

Source

impl<const N: usize> Vector2D<Num<i32, N>>

pub fn magnitude(self) -> Num<i32, N>

Calculates the magnitude by square root

let v1: Vector2D<Num<i32, 8>> = (num!(3.), num!(4.)).into();
assert_eq!(v1.magnitude(), 5.into());
pub fn fast_magnitude(self) -> Num<i32, N>

Calculates the magnitude of a vector using the alpha max plus beta min algorithm this has a maximum error of less than 4% of the true magnitude, probably depending on the size of your fixed point approximation

let v1: Vector2D<Num<i32, 8>> = (num!(3.), num!(4.)).into();
assert!(v1.fast_magnitude() > num!(4.9) && v1.fast_magnitude() < num!(5.1));
pub fn normalise(self) -> Vector2D<Num<i32, N>>

Normalises the vector to magnitude of one by performing a square root, due to fixed point imprecision this magnitude may not be exactly one

let v1: Vector2D<Num<i32, 8>> = (num!(4.), num!(4.)).into();
assert_eq!(v1.normalise().magnitude(), 1.into());
pub fn fast_normalise(self) -> Vector2D<Num<i32, N>>

Normalises the vector to magnitude of one using Vector2D::fast_magnitude.

let v1: Vector2D<Num<i32, 8>> = (num!(4.), num!(4.)).into();
assert_eq!(v1.fast_normalise().magnitude(), 1.into());
Source

impl<T> Vector2D<T>
where T: Number,

pub fn change_base<U>(self) -> Vector2D<U>
where U: Number + From<T>,

Converts the representation of the vector to another type

let v1: Vector2D<i16> = vec2(1, 2);
let v2: Vector2D<i32> = v1.change_base();
Source

impl<I, const N: usize> Vector2D<Num<I, N>>

pub fn new_from_angle(angle: Num<I, N>) -> Vector2D<Num<I, N>>

Creates a unit vector from an angle, noting that the domain of the angle is [0, 1], see Num::cos and Num::sin.

let v: Vector2D<Num<i32, 8>> = Vector2D::new_from_angle(num!(0.0));
assert_eq!(v, (num!(1.0), num!(0.0)).into());
Source

impl<T> Vector2D<T>
where T: Number,

pub const fn new(x: T, y: T) -> Vector2D<T>

Created a vector from the given coordinates.

You should use vec2() instead.

let v = Vector2D::new(1, 2);
assert_eq!(v.x, 1);
assert_eq!(v.y, 2);
pub fn get(self) -> (T, T)

Returns the tuple of the coordinates

let v = vec2(1, 2);
assert_eq!(v.get(), (1, 2));
pub fn hadamard(self, other: Vector2D<T>) -> Vector2D<T>

Calculates the hadamard product of two vectors

let v1 = vec2(2, 3);
let v2 = vec2(4, 5);

let r = v1.hadamard(v2);
assert_eq!(r, vec2(v1.x * v2.x, v1.y * v2.y));
pub fn dot(self, b: Vector2D<T>) -> T

Calculates the dot product / scalar product of two vectors

use agb_fixnum::vec2;

let v1 = vec2(3, 5);
let v2 = vec2(7, 11);

let dot = v1.dot(v2);
assert_eq!(dot, 76);

The dot product for vectors A and B is defined as

Ax × Bx + Ay × By.

pub fn cross(self, b: Vector2D<T>) -> T

Calculates the z component of the cross product / vector product of two vectors

use agb_fixnum::vec2;

let v1 = vec2(3, 5);
let v2 = vec2(7, 11);

let dot = v1.cross(v2);
assert_eq!(dot, -2);

The z component cross product for vectors A and B is defined as

Ax × By - Ay × Bx.

Normally the cross product / vector product is itself a vector. This is in the 3D case where the cross product of two vectors is perpendicular to both vectors. The only vector perpendicular to two 2D vectors is purely in the z direction, hence why this method only returns that component. The x and y components are always zero.

pub fn swap(self) -> Vector2D<T>

Swaps the x and y coordinate

let v1 = vec2(2, 3);
assert_eq!(v1.swap(), vec2(3, 2));
pub fn magnitude_squared(self) -> T

Calculates the magnitude squared, ie (xx + yy)

let v1: Vector2D<Num<i32, 8>> = (num!(3.), num!(4.)).into();
assert_eq!(v1.magnitude_squared(), 25.into());