Module input

Module input 

Button inputs to the system.

Structs

ButtonController
Helper to make it easy to get the current state of the GBA’s buttons.
ButtonState
Represents the state of potentially multiple buttons being pressed at once

Enums

Button
Represents a button on the GBA
Tri
Tri-state enum. Allows for -1, 0 and +1. Useful if checking if the D-Pad is pointing left, right, or unpressed.