VBlank

Struct VBlank 

#[non_exhaustive]
pub struct VBlank { /* private fields */ }
A light weight VBlank handle.

Will set up the VBlank interrupt handler such that the VBlank interrupt can be waited for. Has internal logic to make missing the VBlank less of an issue by keeping track of the number of VBlanks that has occurred.

use agb::interrupt::VBlank;

let vblank = VBlank::get();

vblank.wait_for_vblank();

Implementations

Source

impl VBlank

pub fn get() -> Self

Handles setting up everything required to be able to use the wait for interrupt syscall.

pub fn wait_for_vblank(&self)

Pauses CPU until vblank interrupt is triggered where code execution is resumed.

Not available in embassy mode - use embassy-agb’s async wait_for_vblank instead.