macro_rules! include_aseprite_256 {
($v: vis mod $module: ident, $($aseprite_args: tt)*) => { ... };
}Expand description
Includes sprites found in the referenced aseprite files.
This will optimise to a single multi palette, 256 colour sprites.
use agb::include_aseprite_256;
include_aseprite_256!(
mod sprites,
"examples/gfx/chicken.aseprite"
);
use sprites::{JUMP, WALK, IDLE};Like include_aseprite!, you can specify a target sprite size before a
file path to split frames into smaller sprites. See include_aseprite!
for details.