println

Macro println 

macro_rules! println {
    ($( $x:expr ),*) => { ... };
}
Works like std::println.

Prints to the standard output when running under the mgba emulator. This is mainly useful for debugging, and is reasonably slow.

agb::println!("Hello, World!");

let variable = 5;
agb::println!("format {variable} argument");