#[non_exhaustive]pub struct TimerController {}Expand description
A distributor of timers that binds the timers lifetime to that of the Gba struct to try ensure unique access to timers.
Implementations
Sourceimpl TimerController
impl TimerController
Sourcepub unsafe fn all_timers(&mut self) -> AllTimers<'_>
pub unsafe fn all_timers(&mut self) -> AllTimers<'_>
Gets all timers including system ones (Timer0, Timer1)
Safety
Timer0 and Timer1 are used by system components (sound, embassy-agb). Using them may interfere with system functionality.