Provides access to the GBA’s direct memory access (DMA) for advanced graphical effects.
Structs
- DmaControllable
- A struct to describe things you can modify using DMA (normally some register within the GBA)
- HBlank
Dma - A Dma that copies a value to a given destination each hblank.