macro_rules! include_font {
($font_path: literal, $font_size: literal) => { ... };
}Expand description
Includes a ttf font to be usable by dynamic font rendering.
The first parameter is the filepath and the second is the point size of the font.
use agb::{display::font::Font, include_font};
static FONT: Font = include_font!("fnt/ark-pixel-10px-proportional-latin.ttf", 10);